@@ -14,8 +14,8 @@ import (
 
 	fakeworkclient "github.com/open-cluster-management/api/client/work/clientset/versioned/fake"
 	workv1 "github.com/open-cluster-management/api/work/v1"
-	mockaws "github.com/open-cluster-management/submariner-addon/pkg/cloud/aws/client/mock"
-	testinghelpers "github.com/open-cluster-management/submariner-addon/pkg/helpers/testing"
+	mockaws "github.com/stolostron/submariner-addon/pkg/cloud/aws/client/mock"
+	testinghelpers "github.com/stolostron/submariner-addon/pkg/helpers/testing"
 
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
