@@ -18,12 +18,12 @@ import (
 	clusterinformers "github.com/open-cluster-management/api/client/cluster/informers/externalversions"
 	workclient "github.com/open-cluster-management/api/client/work/clientset/versioned"
 	workinformers "github.com/open-cluster-management/api/client/work/informers/externalversions"
-	configclient "github.com/open-cluster-management/submariner-addon/pkg/client/submarinerconfig/clientset/versioned"
-	configinformers "github.com/open-cluster-management/submariner-addon/pkg/client/submarinerconfig/informers/externalversions"
-	"github.com/open-cluster-management/submariner-addon/pkg/helpers"
-	"github.com/open-cluster-management/submariner-addon/pkg/hub/submarineraddonagent"
-	"github.com/open-cluster-management/submariner-addon/pkg/hub/submarineragent"
-	"github.com/open-cluster-management/submariner-addon/pkg/hub/submarinerbroker"
+	configclient "github.com/stolostron/submariner-addon/pkg/client/submarinerconfig/clientset/versioned"
+	configinformers "github.com/stolostron/submariner-addon/pkg/client/submarinerconfig/informers/externalversions"
+	"github.com/stolostron/submariner-addon/pkg/helpers"
+	"github.com/stolostron/submariner-addon/pkg/hub/submarineraddonagent"
+	"github.com/stolostron/submariner-addon/pkg/hub/submarineragent"
+	"github.com/stolostron/submariner-addon/pkg/hub/submarinerbroker"
 	apiextensionsclientset "k8s.io/apiextensions-apiserver/pkg/client/clientset/clientset"
 	apiextensionsinformers "k8s.io/apiextensions-apiserver/pkg/client/informers/externalversions"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
